flutter_taxcalculate library
A Dart package for calculating taxes on prices, supporting both inclusive and exclusive tax calculations.
Classes
- Tax
- Represents a tax with a name and rate
- TaxCalculator
- A class that handles tax calculations
A Dart package for calculating taxes on prices, supporting both inclusive and exclusive tax calculations.